#
# spec file for package dunst
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?_userunitdir:%define _userunitdir %{_prefix}/lib/systemd/user}
Name:           dunst
Version:        1.9.2
Release:        1.1
Summary:        A customizable notification daemon
License:        BSD-3-Clause
Group:          System/GUI/Other
URL:            https://dunst-project.org
Source:         https://github.com/dunst-project/dunst/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xscrnsaver)

%description
Dunst is a customizable replacement for the notification daemons
provided by most desktop environments.

%prep
%setup -q
%autopatch -p1

%build
%make_build SYSCONFDIR=%{_sysconfdir} all dunstify

%install
%make_install PREFIX=%{_prefix} SYSCONFDIR=%{_sysconfdir}

%files
%doc CHANGELOG.md README.md
%license LICENSE
%dir %{_sysconfdir}/dunst
%config %{_sysconfdir}/dunst/dunstrc
%{_bindir}/dunst
%{_bindir}/dunstify
%{_bindir}/dunstctl
%{_datadir}/dbus-1/services/org.knopwob.dunst.service
%{_userunitdir}/dunst.service
%{_mandir}/man1/dunst.1%{?ext_man}
%{_mandir}/man5/dunst.5%{?ext_man}
%{_mandir}/man1/dunstctl.1%{?ext_man}

%changelog
* Wed Oct 11 2023 Tomas Cech <sleep_walker@opensuse.org>
- update to 1.9.2:
  * Fixed various documentation issues
  * Fixed high cpu when `show_age_treshold` = -1
  * High cpu usage in some situation, often correlated with being idle
* Tue Mar 28 2023 Dirk Müller <dmueller@suse.com>
- update to 1.9.1:
  * zsh completion for dunst and dunstctl (#1107 and #1108)
  * dunstctl `history-clear` command to delete all notifications
    from history (#1131)
  * dunstctl `history-rm command` to remove a single notification
    from history (#1128)
  * `progress_bar_corner_radius` option for adding rounded
    corners to the progress bar (off by default) (#1119)
  * `icon_corner_radius` option for adding rounded corners to
    notification icons (#1139)
  * Make libnotify and dunstify optional in build (#1129)
  * Man page typo's and readability (#1088 and #1121)
  * Length changes not being emitted over D-Bus (#1127)
  * Crash when locking screen with swaylock on Sway (#1148)
  * Dunst using 100%% in some configurations with `idle_threshold`
    turned on (#1140)
* Mon Jan 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.9.0:
  * `override_dbus_timeout` setting to override the notification timeout set
    via dbus.
  * Support notification gaps via the `gap_size` setting. Note that since
    the notifications are not separate windows, you cannot click in between the
    notifications.
  * Make `min_icon_size` and `max_icon_size` a rule for even more
    flexibility
  * The window offset is now scaled according to `scale` as well. This way
    notification stay visually in the same place on higher DPI screens.
  * For the recursive icon lookup, revert to using `min_icon_size` and
    `max_icon_size` instead of `icon_size`. `min_icon_size` is used as the size to
    look for in icon themes.
  * Recursive icon lookup is no longer experimental.
  * Recursive icon lookup is enabled in the default dunstrc. This does not
    change your settings when you have a custom dunstrc.
  * Added back the `action_name` setting that was accidentally dropped.
  * Broken `dunstctl history`.
  * Merged a few wayland fixes from mako (https://github.com/emersion/mako)
  * `follow=keyboard`: Fix regression where we don't fall back to mouse
  * Raw icons not being scaled according to icon size
  * Notifications not disappearing. For some people notifications would
    sometimes stay on screen until a new notification appeared. This should
    not happen anymore
* Thu Apr 14 2022 Timothy Brown <stimut@gmail.com>
- Update to 1.8.1
  * release notes:
    https://github.com/dunst-project/dunst/blob/master/CHANGELOG.md
* Tue Dec  7 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to 1.7.2
  * release notes:
    https://github.com/dunst-project/dunst/blob/master/CHANGELOG.md
- Drop unneeded patch:
  * makefile.patch
- Drop upstreamed patch:
  * dunst-xdg-open-can-open-URLs-don-t-rely-on-specific-hardco.patch
* Fri Jul  2 2021 Michal Suchanek <msuchanek@suse.com>
- Do not hardcode web browser
  + dunst-xdg-open-can-open-URLs-don-t-rely-on-specific-hardco.patch
* Thu Apr 29 2021 Jan Baier <jbaier@suse.com>
- update to 1.6.1
- refresh makefile.patch
  * Added
  - Wayland support. Dunst now runs natively on wayland. This fixes several bugs with dunst on wayland and allows idle detection. (#781)
  - A progress bar, useful for showing volume or brightness in notifications (#775)
  - A script in contrib for using the progress bar (#791)
  - dunstctl count for showing the number of notifications (#793)
  - Expose environment variables info about the notification to scripts (#802)
  - text_icon_padding for adding padding between the notification icon and text (#810)
  * Changed
  - Dunst now installs a system-wide config in /etc/dunst/dunstrc (#798)
  - Move part of the man page to dunst(5) (#799)
  * Fixed
  - Incorrect version in Makefile
  - history_ignore flag broken when using multiple rules (#747)
  - Divide by zero in radius calculation (#750)
  - Monitor setting overriding follow_mode (#755)
  - Incorrect monitor usage when using multiple X11 screens (#762)
  - Emit signal when paused property changes (#766)
  - dunstify can pass empty appname to libnotify (#768)
  - Incorrect handling of 'do_action, close' mouse action (#778)
  * Removed
  - DUNST_COMMAND_{PAUSE,RESUME,TOGGLE} (#830)-
* Sat Aug  8 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.5.0
- refresh makefile.patch
  * min_icon_size option to automatically scale up icons to a desired value
  * vertical_alignment option to control the text/icon alignment within the notification
  * Ability to configure multiple actions for each mouse event
  * dunstctl command line control client
  * RGBA support for all color strings
  * Ability to run multiple scripts for each notification
  * ignore_dbusclose setting
  * dunstify notification client is now installed by default
  * Keyboard follow mode falls back to the monitor with the mouse if no window has keyboard focus
  * Overflow when setting a >=40 minute timeout
  * Unset configuration options not falling back to default values
  * Crash when $HOME environment variable is unset
  * Lack of antialiasing with round corners enabled
* Wed Jul  3 2019 Ondřej Súkup <mimi.vx@gmail.com>
- Update to version 1.4.1
  * max_icon_size not working with dynamic width
  * Failure to parse color strings with trailing comments in the config
  * Negative width in geometry being ignored
  * Incorrect handling of the argument terminator -- in dunstify
  * Crash when changing DPI while no notifications are displayed
  * Fullscreen status change not being detected in some cases
* Tue May 28 2019 Petr Cervinka <petr@cervinka.net>
- Update to version 1.4.0
  * Added
  - Add support to override `frame_color` via rules (#498)
  - Support for round corners (#420)
  - Ability to reference `$HOME` in icon paths with `~/` (#520)
  - Support to customize the mouse bindings (#530)
  - Command to toggle pause status (#535)
  - Ability to automatically replace similar notifications (like volume changes)
    via `stack_tag` (#552)
  - Comparison of raw icons for duplicate notifications (#571)
  - Introduce new desktop-entry filter (#470)
  - `fullscreen` rule to hide notifications when a fullscreen window is active (#472)
  - Added `skip_display` rule option to skip initial notification display, and
    include the notification in the history. (#590)
  * Fixed
  - Notification age not counting the time while the computer was suspended (#492)
  - Dunst losing always-on-top status on a window manager restart (#160)
  - Xpm icons not being recognized
  - When new notifications arrive, but display is full, important notifications don't
    have to wait for a timeout in a displayed notification (#541)
  - Dunst hanging while the context menu is open (#456)
  - Having & inside a notification breaking markup (#546)
  - `<I> more` notifications don't occupy space anymore, if there is only a single
    notification waiting to get displayed. The notification gets displayed directly (#467)
  - Segfault when comparing icon name with a notification with a raw icon (#536)
  - Icon size can no longer be larger than the notification when a fixed width is specified (#540)
  * Changed
  - Transient notifications no longer skip history by default (#508)
  - The notification summary no longer accepts markup (#497)
  * Removed
  - Dependency on libxdg-basedir (#550)
- Update makefile.patch to be compatible with latest version
- Build and install dunstify binary, command which is completely compatible to notify-send
  and can be used alongside it, but offers more features.
* Sun May  6 2018 avindra@opensuse.org
- update to version 1.3.2
  * Fix crash when loading invalid or corrupt icon file
- minor cleanup with spec-cleaner
- use %%make_install macro
* Tue Feb 20 2018 mimi.vx@gmail.com
- add makefile.patch to fix service installation
* Sun Feb 11 2018 jengelh@inai.de
- Trim filler wording from description.
* Wed Feb  7 2018 arun@gmx.de
- specfile:
  * updated copyright year
  * changed dependency gdk-2.0 to gdk-pixbuf-2.0
- update to version 1.3.1
  * Race condition resulting in the service files being empty (#488)
- changes from version 1.3.0:
  * Added
    + ellipsize option to control how long lines should be ellipsized
    when word_wrap is set to false (#374)
    + A beginning tilde of a path is now expanded to the home of the
    current user (#351)
    + The image-path hint is now respected, as GApplications send
    their icon only via this link (#447)
    + The (legacy) image_data hint is now respected (#353)
    + If dunst can't acquire the DBus name, dunst prints the PID of
    the process holding the name (#458 #460)
    + Increased accuracy of timeouts by using microseconds internally
    (#379 #291)
    + Support for specifying timeout values in milliseconds, minutes,
    hours, or days. (#379)
    + Support for HTML img tags (via context menu) (#428)
  * Fixed
    + new_icon rule being ignored on notifications that had a raw icon
    (#423)
    + Format strings being replaced recursively in some cases (#322
    [#365])
    + DBus related memory leaks (#397)
    + Crash on X11 servers with RandR support less than 1.5. (#413
    [#364])
    + Silently reading the default config file, if -conf did not
    specify a valid file (#452)
    + Notification window flickering when a notification is replaced
    (#320 #415)
    + Inaccurate timeout in some cases (#291 #379)
  * Changed
    + Transient hints are now handled (#343 #310) An additional rule
    option (match_transient and set_transient) is added to
    optionally reset the transient setting
    + HTML links are now referred to by their text in the context menu
    rather than numbers (#428)
    + icon_folders setting renamed to icon_path (#170)
    + config.def.h and config.h got merged (#371)
    + The dependency on GTK3+ has been removed. Instead of GTK3+,
    dunst now requires gdk-pixbuf which had been a transient
    dependency before. (#334 #376)
    + The _GNU_SOURCE macros had been removed to make dunst portable
    to nonGNU systems (#403)
    + Internal refactorings of the notification queue handling. (#411)
    + Dunst does now install the systemd and dbus service files into
    their proper location given by pkg-config. Use
    SERVICEDIR_(DBUS|SYSTEMD) params to overwrite them. (#463)
* Sat Jul 22 2017 mimi.vx@gmail.com
- update to 1.2.0
- dropped dunst_bad_free.patch
  * always_run_script option to run script even if a notification is suppressed
  * Support for more icon file types
  * Support for raw icons
  * hide_duplicate_count option to hide the number of duplicate notifications
  * Support for per-urgency frame colours
  * markup setting for more fine-grained control over how markup is handled
  * history_ignore rule action to exclude a notification from being
  added to the history
  * Support for setting the dpi value dunst will use for font rendering
  via the Xft.dpi X resource
  * Experimental support for per-monitor dpi calculation
  * max_icon_size option to scale down icons if they exceed a certain size
  * Middle click on notifications can be used to trigger actions
  * Systemd service file, installed by default
  * %%n format flag for getting progress value without any extra characters
  * Text and icons are now centred vertically
  * Notifications aren’t considered duplicate if urgency or icons differ
  * The maximum length of a notification is limited to 5000 characters
  * The frame width and color settings were moved to the global section
  as frame_width and frame_color respectively
  * Dropped Xinerama in favour of RandR, Xinerama can be enabled with
  the -force_xinerama option if needed
  * allow_markup is deprecated with markup as its replacement
  * The urgency specific command line flags have been deprecated with
  no replacement, respond to issue #328 on the bug tracker
  if you depend on them
  * Infinite loop if there are 2 configuration file sections with the same name
  * URLs with dashes and underscores in them are now parsed properly
  * Many memory leaks
  * Category based rules were applied without actually matching
  * dmenu command not parsing quoted arguments correctly
  * Icon alignment with dynamic width
  * Issue when loading configuration files with very long lines
  * ‘\n’ is no longer expanded to a newline inside notification text
  * Notification window wasn’t redrawn if obscured on systems without a compositor
  * ignore_newline now works regardless of the markup setting
  * dmenu process being left as a zombie if no option was selected
  * Crash when opening urls parsed from <a href=""> tags
* Sat Jan 21 2017 mimi.vx@gmail.com
- removed unneded deps
- fixed bad free and memory leak by dunst_bad_free.patch
* Thu Jun 18 2015 mimi.vx@gmail.com
- update to 1.1.0
  * bugfixes ( memmory leak on Spotify )
  * icons
- spec-cleaned
* Wed May 29 2013 fcastelli@suse.com
- created initial package (1.0.0)
